HasAddr

Trait HasAddr 

pub trait HasAddr<T = Self> {
    // Required method
    fn addr(&self) -> Cow<'_, Node<T>>;
}
A trait implemented by values which have a strong node address associated with them

Required Methods

fn addr(&self) -> Cow<'_, Node<T>>

Get a Cow of the strong node address associated with this value

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> HasAddr<T> for Node<T>