HasThis

Trait HasThis 

pub trait HasThis<T = Self> {
    // Required method
    fn this(&self) -> Cow<'_, WeakNode<T>>;
}
A trait implemented by values which have a weak node address associated with them

Required Methods

fn this(&self) -> Cow<'_, WeakNode<T>>

Get a Cow of the weak node address associated with this value. May be null if there is none.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> HasThis<T> for Node<T>

Source

impl<T> HasThis<T> for WeakNode<T>