parse_atom

Function parse_atom 

pub fn parse_atom(input: &str) -> IResult<&str, Expr<'_>>
Parse an atomic rain expression Does not accept whitespace before the expression, and does not consume whitespace after it.